@@ -2,6 +2,8 @@
 #include <utmp.h>
 #include "defines.h"
 
+//#define	CLAMSMTP
+
 extern char callsign[20];
 extern char username[20];
 extern char fullname[31];
@@ -9,6 +11,7 @@ extern char forward[79];
 
 extern char *homedir;		/* User's home directory */
 extern char *fwdfile;		/* User's .forward file (~/.forward) */
+extern char *sigfile;		/* User's .signature file (~/.signature) */
 extern char *maildir;		/* User's mail directory (~/mail) */
 extern char *mailbox;		/* System mailbox (/var/spool/mail/user) */
 extern char *userbox;		/* User's mailbox (~/mbox) */
@@ -24,6 +27,7 @@ extern char *tempMesg;
 
 extern char *faxgate;		/* Email of your E-Fax Gateway */
 extern char *hostname;
+extern char *sysopmail;
 extern char *def_shell;		/* Default settings for autoaccounts */
 extern char *def_homedir;
 
